@@ -4,7 +4,6 @@
 
 #pragma once
 
-#include "VideoStream.h"
 #include "krdp_export.h"
 
 #include <PipeWireEncodedStream>
@@ -12,6 +11,7 @@
 
 namespace KRdp
 {
+struct VideoFrame;
 class Server;
 
 struct VirtualMonitor {
@@ -24,7 +24,7 @@ class KRDP_EXPORT AbstractSession : public QObject
 {
     Q_OBJECT
 public:
-    AbstractSession(Server *server);
+    AbstractSession();
     ~AbstractSession() override;
 
     /**
